@@ -1,7 +1,7 @@
 package Data::Clean;
 
 our $DATE = '2018-10-09'; # DATE
-our $VERSION = '0.500'; # VERSION
+our $VERSION = '0.501'; # VERSION
 
 use 5.010001;
 use strict;
@@ -292,7 +292,7 @@ Data::Clean - Clean data structure
 
 =head1 VERSION
 
-This document describes version 0.500 of Data::Clean (from Perl distribution Data-Clean), released on 2018-10-09.
+This document describes version 0.501 of Data::Clean (from Perl distribution Data-Clean), released on 2018-10-09.
 
 =head1 SYNOPSIS
 
@@ -370,6 +370,9 @@ array-based objects because they will be recursed instead.
 Set fully qualified name of clone function to use. The default is to use
 C<Sereal::Dclone::dclone> if available, or fallback to C<Clone::PP::clone>.
 
+The clone module (all but the last part of the C<!clone_func> value) will
+automatically be loaded using C<require()>.
+
 =back
 
 Available commands:
